@@ -80,7 +80,7 @@ sub _cpanm ($self) {
 
         # install known platform exceptions without tests
         if ( exists $cfg->{cpan_notest}->{ $Config{archname} } && $cfg->{cpan_notest}->{ $Config{archname} }->@* ) {
-            P->pm->run_check( 'cpanm', '--notest', $cfg->{cpan_notest}->{ $Config{archname} }->@* ) or return;
+            P->pm->run_proc( [ 'cpanm', '--notest', $cfg->{cpan_notest}->{ $Config{archname} }->@* ] ) or return;
         }
 
         my @args = (    #
@@ -95,7 +95,7 @@ sub _cpanm ($self) {
 
         say join q[ ], @args;
 
-        P->pm->run_check(@args) or return;
+        P->pm->run_proc( \@args ) or return;
     }
 
     return 1;
@@ -118,12 +118,12 @@ sub _install ($self) {
         if ( $self->dist->is_pcore ) {
 
             # set $ENV{PERL5LIB}
-            P->pm->run_check(qq[setx.exe /M PERL5LIB "$canon_dist_root/lib;"]) or return;
+            P->pm->run_proc(qq[setx.exe /M PERL5LIB "$canon_dist_root/lib;"]) or return;
 
             say qq[%PERL5LIB% updated];
 
             # set $ENV{PCORE_LIB}
-            P->pm->run_check(qq[setx.exe /M PCORE_LIB "$pcore_lib_dir_canon"]) or return;
+            P->pm->run_proc(qq[setx.exe /M PCORE_LIB "$pcore_lib_dir_canon"]) or return;
 
             say qq[%PCORE_LIB% updated];
         }
@@ -144,7 +144,7 @@ sub _install ($self) {
 
             $ENV{PATH} = join $Config{path_sep}, @system_path;    ## no critic qw[Variables::RequireLocalizedPunctuationVars]
 
-            P->pm->run_check(qq[setx.exe /M PATH "$ENV{PATH};"]) or return;
+            P->pm->run_proc(qq[setx.exe /M PATH "$ENV{PATH};"]) or return;
 
             say qq[%PATH% updated];
         }
