@@ -21,10 +21,10 @@ sub _build_api ($self) {
     my $scm_upstream = $self->dist->scm->upstream;
 
     return Pcore::API::Bitbucket->new(
-        {   account_name => $scm_upstream->username,
-            repo_slug    => $scm_upstream->reponame,
-            username     => $self->dist->build->user_cfg->{Bitbucket}->{api_username},
-            password     => $self->dist->build->user_cfg->{Bitbucket}->{api_password},
+        {   repo_owner   => $scm_upstream->repo_owner,
+            repo_name    => $scm_upstream->repo_name,
+            api_username => $ENV->user_cfg->{'Pcore::API::Bitbucket'}->{api_username},
+            api_password => $ENV->user_cfg->{'Pcore::API::Bitbucket'}->{api_password},
         }
     );
 }
@@ -167,8 +167,6 @@ sub create_milestone ( $self, $milestone, $cb ) {
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
 ## │    3 │ 68, 72               │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    2 │ 24                   │ ValuesAndExpressions::ProhibitLongChainsOfMethodCalls - Found method-call chain of length 4                    │
-## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
 ## │    1 │ 140                  │ BuiltinFunctions::ProhibitReverseSortBlock - Forbid $b before $a in sort blocks                                │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
