@@ -1,9 +1,9 @@
 package Pcore::Dist::Build::Release;
 
 use Pcore -class;
-use Pcore::Util::Text qw[encode_utf8];
 use Pod::Markdown;
 use CPAN::Meta;
+use Pcore::API::PAUSE;
 
 has dist => ( is => 'ro', isa => InstanceOf ['Pcore::Dist'], required => 1 );
 
@@ -12,7 +12,7 @@ has minor  => ( is => 'ro', isa => Bool, default => 0 );
 has bugfix => ( is => 'ro', isa => Bool, default => 0 );
 
 sub run ($self) {
-    if ( $self->dist->cfg->{dist}->{cpan} && !$self->dist->build->user_cfg || ( !$self->dist->build->user_cfg->{PAUSE}->{username} || !$self->dist->build->user_cfg->{PAUSE}->{password} ) ) {
+    if ( $self->dist->cfg->{dist}->{cpan} && !$ENV->user_cfg->{'Pcore::API::PAUSE'}->{username} || !$ENV->user_cfg->{'Pcore::API::PAUSE'}->{password} ) {
         say qq[You need to specify PAUSE credentials$LF];
 
         return;
@@ -27,7 +27,7 @@ sub run ($self) {
     my $scm = $self->dist->scm->server;
 
     # check for uncommited changes
-    if ( $scm->cmd(qw[status -mardu --subrepos])->%* ) {
+    if ( $self->dist->has_uncommited_changes ) {
         say qq[Working copy or subrepos has uncommited changes or unknown files. Release is impossible.$LF];
 
         return;
@@ -52,7 +52,7 @@ sub run ($self) {
     }
 
     # show current and new versions, take confirmation
-    my $cur_ver = $self->dist->version;
+    my $cur_ver = $self->dist->last_release_version;
 
     # increment version
     my @parts = $cur_ver->{version}->@*;
@@ -67,7 +67,9 @@ sub run ($self) {
         $parts[2] = 0;
     }
     elsif ( $self->bugfix ) {
-        $parts[2]++;
+
+        # bugfix is impossible for v0.0.0
+        $parts[2]++ if $cur_ver ne 'v0.0.0';
     }
 
     my $new_ver = version->parse( 'v' . join q[.], @parts );
@@ -90,7 +92,7 @@ sub run ($self) {
         say qq[\nNo issues were closed since the last release];
     }
 
-    say qq[${LF}Curent version is: $cur_ver];
+    say qq[${LF}Current version is: $cur_ver];
     say qq[New version will be: $new_ver$LF];
 
     return if P->term->prompt( qq[Continue release process?], [qw[yes no]], enter => 1 ) ne 'yes';
@@ -117,7 +119,7 @@ sub run ($self) {
         my $cv = AE::cv;
 
         # create new version on issues tracker
-        print q[Create new version and milestone on issues tracker ... ];
+        print q[Creating new version and milestone on issues tracker ... ];
 
         $cv->begin;
 
@@ -210,17 +212,29 @@ sub _upload_to_cpan ($self) {
     say 'done';
 
   REDO:
-    print 'Upload to CPAN ... ';
+    print 'Uploading to CPAN ... ';
 
-    my ( $status, $reason ) = $self->_upload( $self->dist->build->user_cfg->{PAUSE}->{username}, $self->dist->build->user_cfg->{PAUSE}->{password}, $tgz );
+    my $pause = Pcore::API::PAUSE->new(
+        {   username => $ENV->user_cfg->{'Pcore::API::PAUSE'}->{username},
+            password => $ENV->user_cfg->{'Pcore::API::PAUSE'}->{password},
+        }
+    );
 
-    if ( $status == 200 ) {
-        say $reason;
+    my $res = $pause->upload($tgz);
+
+    if ( $res->is_success ) {
+        say $res->reason;
 
         unlink $tgz or 1;
+
+        print q[Removing old distributions from PAUSE ... ];
+
+        $pause->clean;
+
+        say 'done';
     }
     else {
-        say qq[$status $reason];
+        say join q[ ], $res->status, $res->reason;
 
         goto REDO if P->term->prompt( 'Retry?', [qw[yes no]], enter => 1 );
 
@@ -230,75 +244,6 @@ sub _upload_to_cpan ($self) {
     return;
 }
 
-sub _upload ( $self, $username, $password, $path ) {
-    my $body;
-
-    encode_utf8 $username;
-
-    encode_utf8 $password;
-
-    $path = P->path($path);
-
-    my $boundary = P->random->bytes_hex(64);
-
-    state $pack_multipart = sub ( $name, $body_ref, $filename = q[] ) {
-        $body .= q[--] . $boundary . $CRLF;
-
-        $body .= qq[Content-Disposition: form-data; name="$name"];
-
-        $body .= qq[; filename="$filename"] if $filename;
-
-        $body .= $CRLF;
-
-        $body .= $CRLF;
-
-        $body .= $body_ref->$*;
-
-        $body .= $CRLF;
-
-        return;
-    };
-
-    $pack_multipart->( 'HIDDENNAME', \$username );
-
-    $pack_multipart->( 'pause99_add_uri_subdirtext', \q[] );
-
-    $pack_multipart->( 'CAN_MULTIPART', \1 );
-
-    $pack_multipart->( 'pause99_add_uri_upload', \$path->filename );
-
-    $pack_multipart->( 'pause99_add_uri_httpupload', P->file->read_bin($path), $path->filename );
-
-    $pack_multipart->( 'pause99_add_uri_uri', \q[] );
-
-    $pack_multipart->( 'SUBMIT_pause99_add_uri_httpupload', \q[ Upload this file from my disk ] );
-
-    $body .= q[--] . $boundary . q[--] . $CRLF . $CRLF;
-
-    my $status;
-
-    my $reason;
-
-    P->http->post(
-        'https://pause.perl.org/pause/authenquery',
-        headers => {
-            AUTHORIZATION => 'Basic ' . P->data->to_b64_url( $username . q[:] . $password ) . q[==],
-            CONTENT_TYPE  => qq[multipart/form-data; boundary=$boundary],
-        },
-        body      => \$body,
-        blocking  => 1,
-        on_finish => sub ($res) {
-            $status = $res->status;
-
-            $reason = $res->reason;
-
-            return;
-        }
-    );
-
-    return $status, $reason;
-}
-
 sub _create_changes ( $self, $ver, $issues ) {
     state $init = !!require CPAN::Changes;
 
@@ -342,14 +287,14 @@ sub _create_changes ( $self, $ver, $issues ) {
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
 ## │    3 │ 14                   │ Subroutines::ProhibitExcessComplexity - Subroutine "run" with high complexity score (24)                       │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    3 │ 30, 321              │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
+## │    3 │ 98                   │ ValuesAndExpressions::ProhibitInterpolationOfLiterals - Useless interpolation of literal string                │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    3 │ 96                   │ ValuesAndExpressions::ProhibitInterpolationOfLiterals - Useless interpolation of literal string                │
+## │    3 │ 266                  │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    2 │ 15, 44, 47, 82, 87,  │ ValuesAndExpressions::ProhibitLongChainsOfMethodCalls - Found method-call chain of length 4                    │
-## │      │ 108, 124, 138, 215   │                                                                                                                │
+## │    2 │ 44, 47, 84, 89, 110, │ ValuesAndExpressions::ProhibitLongChainsOfMethodCalls - Found method-call chain of length 4                    │
+## │      │ 126, 140             │                                                                                                                │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    1 │ 317                  │ BuiltinFunctions::ProhibitReverseSortBlock - Forbid $b before $a in sort blocks                                │
+## │    1 │ 262                  │ BuiltinFunctions::ProhibitReverseSortBlock - Forbid $b before $a in sort blocks                                │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
