@@ -31,98 +31,46 @@ else {
     open *OUT, '>&=', $BOOT_ARGS->{ipc}->{out} or die $!;    ## no critic qw[InputOutput::RequireBriefOpen]
 }
 
-# create handles
-my $cv = AE::cv;
-
-my ( $in, $out );                                            # in - read, out - write
-
-$cv->begin;
+my $IN;                                                      # read from
+my $OUT;                                                     # write to
 
+# wrap IN
 Pcore::AE::Handle->new(
     fh       => \*IN,
     on_error => sub ( $h, $fatal, $msg ) {
         exit;
     },
     on_connect => sub ( $h, @ ) {
-        $in = $h;
-
-        $cv->end;
+        $IN = $h;
 
         return;
     }
 );
 
-$cv->begin;
-
+# wrap OUT
 Pcore::AE::Handle->new(
     fh       => \*OUT,
     on_error => sub ( $h, $fatal, $msg ) {
         exit;
     },
     on_connect => sub ( $h, @ ) {
-        $out = $h;
-
-        $cv->end;
+        $OUT = $h;
 
         return;
     }
 );
 
-$cv->recv;
-
-# handles are created
-$cv = AE::cv;
-
 # create object
-my $obj = P->class->load( $BOOT_ARGS->{class} )->new( $BOOT_ARGS->{args} );
+my $RPC = P->class->load( $BOOT_ARGS->{class} )->new( $BOOT_ARGS->{buildargs} // () );
 
-my $deps = {};
+my $DEPS    = {};
+my $QUEUE   = {};
+my $CALL_ID = 0;
 
-# create listener
-my $listener = sub ($req) {
-    my $call_id = $req->[0];
-
-    my $method = $req->[1];
-
-    my $responder = sub ( $call_id, $res ) {
-
-        # make PAR deps snapshot after each call
-        my $new_deps;
-
-        if ( $BOOT_ARGS->{scan_deps} ) {
-            for my $pkg ( grep { !exists $deps->{$_} } keys %INC ) {
-                $new_deps = 1;
-
-                $deps->{$pkg} = $INC{$pkg};
-            }
-        }
-
-        my $data = P->data->to_cbor( [ [ $new_deps ? $deps : undef, $call_id, $$ ], $res ] );
-
-        $out->push_write( pack( 'L>', bytes::length $data->$* ) . $data->$* );
-
-        return;
-    };
-
-    if ( !$obj->can($method) ) {
-        $responder->( $call_id, undef );
-    }
-    else {
-        $obj->$method(
-            sub ($data = undef) {
-                $responder->( $call_id, $data );
-
-                return;
-            },
-            $req->[2],
-        );
-    }
-
-    return;
-};
+our $CV = AE::cv;
 
 # start listen
-$in->on_read(
+$IN->on_read(
     sub ($h) {
         $h->unshift_read(
             chunk => 4,
@@ -130,7 +78,7 @@ $in->on_read(
                 $h->unshift_read(
                     chunk => unpack( 'L>', $data ),
                     sub ( $h, $data ) {
-                        $listener->( P->data->from_cbor($data) );
+                        _on_data( P->data->from_cbor($data) );
 
                         return;
                     }
@@ -145,9 +93,83 @@ $in->on_read(
 );
 
 # handshake, send PID
-$out->push_write("READY$$\x00");
+$OUT->push_write("READY$$\x00");
 
-$cv->recv;
+$CV->recv;
+
+sub _on_data ($data) {
+    if ( $data->[0]->{method} ) {
+        _on_call( $data->[0]->{call_id}, $data->[0]->{method}, $data->[1] );
+    }
+    else {
+        if ( my $cb = delete $QUEUE->{ $data->[0]->{call_id} } ) {
+            $cb->( $data->[1] );
+        }
+    }
+
+    return;
+}
+
+sub _on_call_responder ( $call_id, $data ) {
+
+    # make PAR deps snapshot after each call
+    my $new_deps_found;
+
+    if ( $BOOT_ARGS->{scan_deps} ) {
+        for my $pkg ( grep { !exists $DEPS->{$_} } keys %INC ) {
+            $new_deps_found = 1;
+
+            $DEPS->{$pkg} = $INC{$pkg};
+        }
+    }
+
+    my $cbor = P->data->to_cbor(
+        [   {   pid     => $$,
+                call_id => $call_id,
+                deps    => $new_deps_found ? $DEPS : undef,
+            },
+            $data
+        ]
+    );
+
+    $OUT->push_write( pack( 'L>', bytes::length $cbor->$* ) . $cbor->$* );
+
+    return;
+}
+
+sub _on_call ( $call_id, $method, $data ) {
+    if ( !$RPC->can($method) ) {
+        die qq[Unknown RPC method "$method"];
+    }
+    else {
+        my $cb = !defined $call_id ? undef : sub ($data = undef) {
+            _on_call_responder( $call_id, $data );
+
+            return;
+        };
+
+        $RPC->$method( $cb, $data );
+    }
+
+    return;
+}
+
+sub rpc_call ( $self, $method, $data = undef, $cb = undef ) {
+    my $call_id;
+
+    if ($cb) {
+        $call_id = ++$CALL_ID;
+
+        $QUEUE->{$call_id} = $cb;
+    }
+
+    # prepare CBOR data
+    my $cbor = P->data->to_cbor( [ { pid => $$, call_id => $call_id, method => $method }, $data ] );
+
+    $OUT->push_write( pack( 'L>', bytes::length $cbor->$* ) . $cbor->$* );
+
+    return;
+}
 
 1;
 ## -----SOURCE FILTER LOG BEGIN-----
@@ -156,7 +178,7 @@ $cv->recv;
 ## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
 ## │ Sev. │ Lines                │ Policy                                                                                                         │
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
-## │    2 │ 148                  │ ValuesAndExpressions::ProhibitEscapedCharacters - Numeric escapes in interpolated string                       │
+## │    2 │ 96                   │ ValuesAndExpressions::ProhibitEscapedCharacters - Numeric escapes in interpolated string                       │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
