@@ -37,7 +37,7 @@ has root_domain_utf8     => ( is => 'lazy', init_arg => undef );
 
 # NOTE host should be in UTF-8 or ASCII punycoded, UTF-8 encoded - is invalid value
 around new => sub ( $orig, $self, $host ) {
-    $host = to_punycode($host) if utf8::is_utf8($host);
+    $host = domain_to_ascii($host) if utf8::is_utf8($host);
 
     return bless { name => lc $host }, __PACKAGE__;
 };
@@ -47,11 +47,10 @@ sub pub_suffixes ( $self, $force_download = 0 ) {
         my $path = $ENV->share->get('/data/pub_suffix.dat');
 
         if ( !$path || $force_download ) {
-            P->http->get(
+            my $res = P->http->get(
                 'https://publicsuffix.org/list/effective_tld_names.dat',
                 buf_size    => 0,
                 on_progress => 0,
-                blocking    => 1,
                 on_finish   => sub ($res) {
                     if ( $res->status == 200 ) {
                         my $_suffixes = {};
@@ -90,7 +89,7 @@ sub pub_suffixes ( $self, $force_download = 0 ) {
                             }
                         }
 
-                        $path = $ENV->share->store( \join( $LF, sort keys $_suffixes->%* ), '/data/pub_suffix.dat', 'Pcore' );
+                        $path = $ENV->share->store( '/data/pub_suffix.dat', \join( $LF, sort keys $_suffixes->%* ), 'Pcore' );
                     }
 
                     return;
@@ -109,14 +108,13 @@ sub tlds ( $self, $force_download = 0 ) {
         my $path = $ENV->share->get('/data/tld.dat');
 
         if ( !$path || $force_download ) {
-            P->http->get(
+            my $res = P->http->get(
                 'https://data.iana.org/TLD/tlds-alpha-by-domain.txt',
                 buf_size    => 0,
                 on_progress => 0,
-                blocking    => 1,
                 on_finish   => sub ($res) {
                     if ( $res->status == 200 ) {
-                        $path = $ENV->share->store( \encode_utf8( join $LF, sort map { from_punycode(lc) } grep { $_ && !/\A\s*#/smo } split /\n/smo, $res->body->$* ), '/data/tld.dat', 'Pcore' );
+                        $path = $ENV->share->store( '/data/tld.dat', \encode_utf8( join $LF, sort map { domain_to_utf8(lc) } grep { $_ && !/\A\s*#/smo } split /\n/smo, $res->body->$* ), 'Pcore' );
                     }
 
                     return;
@@ -135,7 +133,7 @@ sub to_string ($self) {
 }
 
 sub _build_name_utf8 ($self) {
-    return from_punycode( $self->name );
+    return domain_to_utf8( $self->name );
 }
 
 sub _build_is_ip ($self) {
@@ -209,7 +207,7 @@ sub _build_tld ($self) {
 }
 
 sub _build_tld_utf8 ($self) {
-    return from_punycode( $self->tld );
+    return domain_to_utf8( $self->tld );
 }
 
 sub _build_tld_is_valid ($self) {
@@ -225,7 +223,7 @@ sub _build_canon ($self) {
 }
 
 sub _build_canon_utf8 ($self) {
-    return from_punycode( $self->canon );
+    return domain_to_utf8( $self->canon );
 }
 
 sub _build_is_pub_suffix ($self) {
@@ -284,7 +282,7 @@ sub _build_pub_suffix ($self) {
     }
 
     if ($pub_suffix_utf8) {
-        $pub_suffix_utf8 = to_punycode($pub_suffix_utf8);
+        $pub_suffix_utf8 = domain_to_ascii($pub_suffix_utf8);
 
         return $pub_suffix_utf8;
     }
@@ -294,7 +292,7 @@ sub _build_pub_suffix ($self) {
 }
 
 sub _build_pub_suffix_utf8 ($self) {
-    return from_punycode( $self->pub_suffix );
+    return domain_to_utf8( $self->pub_suffix );
 }
 
 sub _build_is_root_domain ($self) {
@@ -316,7 +314,7 @@ sub _build_root_domain ($self) {
 }
 
 sub _build_root_domain_utf8 ($self) {
-    return from_punycode( $self->root_domain );
+    return domain_to_utf8( $self->root_domain );
 }
 
 1;
@@ -326,9 +324,9 @@ sub _build_root_domain_utf8 ($self) {
 ## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
 ## │ Sev. │ Lines                │ Policy                                                                                                         │
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
-## │    3 │ 72, 79, 93           │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
+## │    3 │ 71, 78, 92           │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    3 │ 269, 272             │ ControlStructures::ProhibitDeepNests - Code structure is deeply nested                                         │
+## │    3 │ 267, 270             │ ControlStructures::ProhibitDeepNests - Code structure is deeply nested                                         │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
